==> ejc-middlemeasurement-impl-3.0.0-20221014.034307-161-sources.jar: com/ejianc/business/middlemeasurement/bean/PurchasesettlementdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度物资采购结算单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_purchasesettlementdetail")
public class PurchasesettlementdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="source")
    private java.lang.String source; // 来源
    @TableField(value="bill_code")
    private java.lang.String billCode; // 材料编码
    @TableField(value="bill_name")
    private java.lang.String billName; // 材料名称
    @TableField(value="brand_model")
    private java.lang.String brandModel; // 品牌/规格型号
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="supply_quantity")
    private java.math.BigDecimal supplyQuantity; // 供货数量
    @TableField(value="supply_time")
    private java.util.Date supplyTime; // 供货时间
    @TableField(value="unit_price")
    private java.math.BigDecimal unitPrice; // 合同单价(除税)(元)
    @TableField(value="tax_unit_price")
    private java.math.BigDecimal taxUnitPrice; // 合同单价(含税)(元)
    @TableField(value="settlement_price")
    private java.math.BigDecimal settlementPrice; // 结算单价(除税)(元)
    @TableField(value="tax_settlement_price")
    private java.math.BigDecimal taxSettlementPrice; // 结算单价(含税)(元)
    @TableField(value="settlement_amount")
    private java.math.BigDecimal settlementAmount; // 结算金额(除税)(元)
    @TableField(value="tax_settlement_amount")
    private java.math.BigDecimal taxSettlementAmount; // 结算金额(含税)(元)
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="settlement_total")
    private java.math.BigDecimal settlementTotal; // 累计结算金额(除税)
    @TableField(value="tax_settlement_total")
    private java.math.BigDecimal taxSettlementTotal; // 累计结算金额(含税)
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编码
    @TableField(value="payment_proportion")
    private java.math.BigDecimal paymentProportion;//合同付款比例
    @TableField(value="material_category")
    private java.lang.String materialCategory; // 物资分类名称
    @TableField(value = "material_category_id")
    private java.lang.String materialCategoryId;
    @TableField(value = "material_category_code")
    private java.lang.String materialCategoryCode;
    @TableField(value="net_price")
    private java.math.BigDecimal netPrice; // 网价
    @TableField(value="float_price")
    private java.math.BigDecimal floatPrice; // 浮动价

    public String getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(String materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public BigDecimal getNetPrice() {
        return netPrice;
    }

    public void setNetPrice(BigDecimal netPrice) {
        this.netPrice = netPrice;
    }

    public BigDecimal getFloatPrice() {
        return floatPrice;
    }

    public void setFloatPrice(BigDecimal floatPrice) {
        this.floatPrice = floatPrice;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }
    /**
     * 材料编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 材料编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 材料名称
     */
    public java.lang.String getBillName() {
        return billName;
    }

    /**
     * 材料名称
     */
    public void setBillName(java.lang.String billName) {
        this.billName = billName;
    }
    /**
     * 品牌/规格型号
     */
    public java.lang.String getBrandModel() {
        return brandModel;
    }

    /**
     * 品牌/规格型号
     */
    public void setBrandModel(java.lang.String brandModel) {
        this.brandModel = brandModel;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 供货数量
     */
    public java.math.BigDecimal getSupplyQuantity() {
        return supplyQuantity;
    }

    /**
     * 供货数量
     */
    public void setSupplyQuantity(java.math.BigDecimal supplyQuantity) {
        this.supplyQuantity = supplyQuantity;
    }
    /**
     * 供货时间
     */
    public java.util.Date getSupplyTime() {
        return supplyTime;
    }

    /**
     * 供货时间
     */
    public void setSupplyTime(java.util.Date supplyTime) {
        this.supplyTime = supplyTime;
    }
    /**
     * 合同单价(除税)(元)
     */
    public java.math.BigDecimal getUnitPrice() {
        return unitPrice;
    }

    /**
     * 合同单价(除税)(元)
     */
    public void setUnitPrice(java.math.BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    /**
     * 合同单价(含税)(元)
     */
    public java.math.BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    /**
     * 合同单价(含税)(元)
     */
    public void setTaxUnitPrice(java.math.BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    /**
     * 结算单价(除税)(元)
     */
    public java.math.BigDecimal getSettlementPrice() {
        return settlementPrice;
    }

    /**
     * 结算单价(除税)(元)
     */
    public void setSettlementPrice(java.math.BigDecimal settlementPrice) {
        this.settlementPrice = settlementPrice;
    }
    /**
     * 结算单价(含税)(元)
     */
    public java.math.BigDecimal getTaxSettlementPrice() {
        return taxSettlementPrice;
    }

    /**
     * 结算单价(含税)(元)
     */
    public void setTaxSettlementPrice(java.math.BigDecimal taxSettlementPrice) {
        this.taxSettlementPrice = taxSettlementPrice;
    }
    /**
     * 结算金额(除税)(元)
     */
    public java.math.BigDecimal getSettlementAmount() {
        return settlementAmount;
    }

    /**
     * 结算金额(除税)(元)
     */
    public void setSettlementAmount(java.math.BigDecimal settlementAmount) {
        this.settlementAmount = settlementAmount;
    }
    /**
     * 结算金额(含税)(元)
     */
    public java.math.BigDecimal getTaxSettlementAmount() {
        return taxSettlementAmount;
    }

    /**
     * 结算金额(含税)(元)
     */
    public void setTaxSettlementAmount(java.math.BigDecimal taxSettlementAmount) {
        this.taxSettlementAmount = taxSettlementAmount;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 累计结算金额(除税)
     */
    public java.math.BigDecimal getSettlementTotal() {
        return settlementTotal;
    }

    /**
     * 累计结算金额(除税)
     */
    public void setSettlementTotal(java.math.BigDecimal settlementTotal) {
        this.settlementTotal = settlementTotal;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettlementTotal() {
        return taxSettlementTotal;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxSettlementTotal(java.math.BigDecimal taxSettlementTotal) {
        this.taxSettlementTotal = taxSettlementTotal;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编码
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 合同付款比例
     */
    public BigDecimal getPaymentProportion() {
        return paymentProportion;
    }
    /**
     * 合同付款比例
     */
    public void setPaymentProportion(BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialCategory() {
        return materialCategory;
    }
    /**
     * 物资分类名称
     */
    public void setMaterialCategory(String materialCategory) {
        this.materialCategory = materialCategory;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20230130.073017-332-sources.jar: com/ejianc/business/middlemeasurement/bean/PurchasesettlementdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度物资采购结算单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_purchasesettlementdetail")
public class PurchasesettlementdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="source")
    private java.lang.String source; // 来源
    @TableField(value="bill_code")
    private java.lang.String billCode; // 材料编码
    @TableField(value="bill_name")
    private java.lang.String billName; // 材料名称
    @TableField(value="brand_model")
    private java.lang.String brandModel; // 品牌/规格型号
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="supply_quantity")
    private java.math.BigDecimal supplyQuantity; // 供货数量
    @TableField(value="supply_time")
    private java.util.Date supplyTime; // 供货时间
    @TableField(value="unit_price")
    private java.math.BigDecimal unitPrice; // 合同单价(除税)(元)
    @TableField(value="tax_unit_price")
    private java.math.BigDecimal taxUnitPrice; // 合同单价(含税)(元)
    @TableField(value="settlement_price")
    private java.math.BigDecimal settlementPrice; // 结算单价(除税)(元)
    @TableField(value="tax_settlement_price")
    private java.math.BigDecimal taxSettlementPrice; // 结算单价(含税)(元)
    @TableField(value="settlement_amount")
    private java.math.BigDecimal settlementAmount; // 结算金额(除税)(元)
    @TableField(value="tax_settlement_amount")
    private java.math.BigDecimal taxSettlementAmount; // 结算金额(含税)(元)
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="settlement_total")
    private java.math.BigDecimal settlementTotal; // 累计结算金额(除税)
    @TableField(value="tax_settlement_total")
    private java.math.BigDecimal taxSettlementTotal; // 累计结算金额(含税)
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编码
    @TableField(value="payment_proportion")
    private java.math.BigDecimal paymentProportion;//合同付款比例
    @TableField(value="material_category")
    private java.lang.String materialCategory; // 物资分类名称
    @TableField(value = "material_category_id")
    private java.lang.Long materialCategoryId;
    @TableField(value = "material_category_code")
    private java.lang.String materialCategoryCode;
    @TableField(value="net_price")
    private java.math.BigDecimal netPrice; // 网价
    @TableField(value="float_price")
    private java.math.BigDecimal floatPrice; // 浮动价

//    public String getMaterialCategoryId() {
//        return materialCategoryId;
//    }
//
//    public void setMaterialCategoryId(String materialCategoryId) {
//        this.materialCategoryId = materialCategoryId;
//    }


    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public BigDecimal getNetPrice() {
        return netPrice;
    }

    public void setNetPrice(BigDecimal netPrice) {
        this.netPrice = netPrice;
    }

    public BigDecimal getFloatPrice() {
        return floatPrice;
    }

    public void setFloatPrice(BigDecimal floatPrice) {
        this.floatPrice = floatPrice;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }
    /**
     * 材料编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 材料编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 材料名称
     */
    public java.lang.String getBillName() {
        return billName;
    }

    /**
     * 材料名称
     */
    public void setBillName(java.lang.String billName) {
        this.billName = billName;
    }
    /**
     * 品牌/规格型号
     */
    public java.lang.String getBrandModel() {
        return brandModel;
    }

    /**
     * 品牌/规格型号
     */
    public void setBrandModel(java.lang.String brandModel) {
        this.brandModel = brandModel;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 供货数量
     */
    public java.math.BigDecimal getSupplyQuantity() {
        return supplyQuantity;
    }

    /**
     * 供货数量
     */
    public void setSupplyQuantity(java.math.BigDecimal supplyQuantity) {
        this.supplyQuantity = supplyQuantity;
    }
    /**
     * 供货时间
     */
    public java.util.Date getSupplyTime() {
        return supplyTime;
    }

    /**
     * 供货时间
     */
    public void setSupplyTime(java.util.Date supplyTime) {
        this.supplyTime = supplyTime;
    }
    /**
     * 合同单价(除税)(元)
     */
    public java.math.BigDecimal getUnitPrice() {
        return unitPrice;
    }

    /**
     * 合同单价(除税)(元)
     */
    public void setUnitPrice(java.math.BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    /**
     * 合同单价(含税)(元)
     */
    public java.math.BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    /**
     * 合同单价(含税)(元)
     */
    public void setTaxUnitPrice(java.math.BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    /**
     * 结算单价(除税)(元)
     */
    public java.math.BigDecimal getSettlementPrice() {
        return settlementPrice;
    }

    /**
     * 结算单价(除税)(元)
     */
    public void setSettlementPrice(java.math.BigDecimal settlementPrice) {
        this.settlementPrice = settlementPrice;
    }
    /**
     * 结算单价(含税)(元)
     */
    public java.math.BigDecimal getTaxSettlementPrice() {
        return taxSettlementPrice;
    }

    /**
     * 结算单价(含税)(元)
     */
    public void setTaxSettlementPrice(java.math.BigDecimal taxSettlementPrice) {
        this.taxSettlementPrice = taxSettlementPrice;
    }
    /**
     * 结算金额(除税)(元)
     */
    public java.math.BigDecimal getSettlementAmount() {
        return settlementAmount;
    }

    /**
     * 结算金额(除税)(元)
     */
    public void setSettlementAmount(java.math.BigDecimal settlementAmount) {
        this.settlementAmount = settlementAmount;
    }
    /**
     * 结算金额(含税)(元)
     */
    public java.math.BigDecimal getTaxSettlementAmount() {
        return taxSettlementAmount;
    }

    /**
     * 结算金额(含税)(元)
     */
    public void setTaxSettlementAmount(java.math.BigDecimal taxSettlementAmount) {
        this.taxSettlementAmount = taxSettlementAmount;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 累计结算金额(除税)
     */
    public java.math.BigDecimal getSettlementTotal() {
        return settlementTotal;
    }

    /**
     * 累计结算金额(除税)
     */
    public void setSettlementTotal(java.math.BigDecimal settlementTotal) {
        this.settlementTotal = settlementTotal;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettlementTotal() {
        return taxSettlementTotal;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxSettlementTotal(java.math.BigDecimal taxSettlementTotal) {
        this.taxSettlementTotal = taxSettlementTotal;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编码
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 合同付款比例
     */
    public BigDecimal getPaymentProportion() {
        return paymentProportion;
    }
    /**
     * 合同付款比例
     */
    public void setPaymentProportion(BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialCategory() {
        return materialCategory;
    }
    /**
     * 物资分类名称
     */
    public void setMaterialCategory(String materialCategory) {
        this.materialCategory = materialCategory;
    }
}
